@@ -1142,12 +1142,18 @@ sub aggregate
     my $function = shift;
     my $expr = shift;
     my $filter = shift;
+    do {
+	$filter = $expr;
+	$expr = Tangram::Expr->new
+	    (Tangram::Number->instance,
+	     '*', $filter->objects);
+    } if $expr->isa("Tangram::Filter");
 
     my @data = $self->select(undef,
 			     ($filter ? (filter => $filter) : ()),
-			     retrieve => [ map { $_->$function() }
-					   (ref ($expr) eq "ARRAY"
-					    ? @$expr : $expr) ],
+			      retrieve => [ map { $_->$function() }
+						(ref ($expr) eq "ARRAY"
+						 ? @$expr : $expr) ],
 			    );
 
     return $data[0]
